﻿using System;

namespace DiskAccessLibrary
{
    public static class DiskImageCreator
    {
        public static DiskImage CreateImage(DiskImageFormat format, DiskImageType type, string imagePath, long imageSize, string snapshotPath, int blockSize)
        {
            switch (format)
            {
                case DiskImageFormat.BlockDifferencingDiskImage:

                    if (type != DiskImageType.Differencing) throw new NotSupportedException();

                    return BlockDifferencingDiskImage.Create(imagePath, snapshotPath, blockSize);

                case DiskImageFormat.RawDiskImage:

                    if (type != DiskImageType.Fixed) throw new NotSupportedException();

                    return RawDiskImage.Create(imagePath, imageSize);

                case DiskImageFormat.VirtualHardDisk:

                    switch (type)
                    {
                        case DiskImageType.Differencing:
                            throw new NotSupportedException();

                        case DiskImageType.Dynamic:
                            return VirtualHardDisk.CreateDynamicDisk(imagePath, imageSize);

                        case DiskImageType.Fixed:
                            return VirtualHardDisk.CreateFixedDisk(imagePath, imageSize);

                        default:
                            throw new ArgumentOutOfRangeException(nameof(type), type, null);
                    }

                default:
                    throw new ArgumentOutOfRangeException(nameof(format), format, null);
            }
        }
    }
}